==> igloo_0_1_5.zip: igloo_0_1_5/igloo/language/1/barnraiser_01/frm_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common.lang.php');


//SECTION
$lang['hdr_latest_subjects'] = 					"latest discussions";
$lang['hdr_subject'] = 							"discussion";
$lang['hdr_subjects'] = 						"subjects";
$lang['hdr_topics'] = 							"topics";
$lang['hdr_topic'] = 							"topic";
$lang['hdr_permissions'] = 						"permissions";
$lang['hdr_latest_comments'] = 					"latest comments";


//A HREF TAGS (links)
$lang['href_topic'] = 							"view topic";
$lang['href_edit_this'] = 						"edit this";
$lang['href_edit_topics'] = 					"edit topics";
$lang['href_add_subject'] = 					"add subject";
$lang['href_see_all_sub'] = 					"go to topic";
$lang['href_latest_discussions'] = 				"latest";


// ERR
$lang['err_no_topics'] = 						"Sorry, there are no topics to display.";
$lang['err_no_subjects'] = 						"Sorry, no discussions available.";


//icons
$lang['ttl_sticky'] = 							"sticky";
$lang['ttl_locked'] = 							"locked";


//BODY TEXT
$lang['txt_topic'] = 							"topic";
$lang['txt_published_to'] = 					"Published to";
$lang['txt_tag_intro'] = 						"My tags";
$lang['txt_item_tag'] = 						"This discussion is tagged with with";
$lang['txt_forum'] = 							"discussions";//breadcrumb
$lang['txt_total_subjects'] = 					"total subjects";
$lang['txt_search_discussions'] = 				"search for discussions";
$lang['txt_comment_total'] = 					"total comments";
$lang['txt_movement'] = 						"movement";
$lang['txt_lastview'] = 						"last viewed";
$lang['txt_watching'] = 						"marked";
$lang['txt_last_comment'] = 					"last comment";
$lang['txt_topic_role_add'] = 					"The following roles can add subjects to this topic";
$lang['txt_sticky'] = 							"sticky";
$lang['txt_locked'] = 							"locked";

$lang['txt_option_items'] = 					"my discussions";
$lang['txt_option_marked'] = 					"marked discussions";
$lang['txt_option_tipped'] = 					"tipped discussions";
$lang['txt_option_list'] = 						"list my discussions";
$lang['txt_option_edit'] = 						"edit this discussion";
$lang['txt_option_edit_topic'] = 				"edit this topic";
$lang['txt_option_add'] = 						"add a discussion";
$lang['txt_option_add_topic'] = 				"add a topic";

?>

==> igloo_0_1_6.zip: igloo_0_1_6/igloo/language/1/barnraiser_01/frm_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common.lang.php');


//SECTION
$lang['hdr_latest_subjects'] = 					"latest discussions";
$lang['hdr_subject'] = 							"discussion";
$lang['hdr_subjects'] = 						"subjects";
$lang['hdr_topics'] = 							"topics";
$lang['hdr_topic'] = 							"topic";
$lang['hdr_permissions'] = 						"permissions";
$lang['hdr_latest_comments'] = 					"latest comments";

$lang['hdr_options'] =							"discussion options";
$lang['hdr_subject_author'] = 					"author";
$lang['hdr_my_network_subjects'] = 				"latest discussions from my network";


//A HREF TAGS (links)
$lang['href_network_subject'] = 				"view their discussions";
$lang['href_view_node'] = 						"latest from the group";
$lang['href_view_network'] = 					"latest from my network";
$lang['href_my_subjects'] = 					"my discussions";
$lang['href_marked'] = 							"marked subjects";
$lang['href_list_subjects'] = 					"list discussions";
$lang['href_add_subject'] = 					"add a discussion to this group";
$lang['href_add_topic'] = 						"add a topic to this group";
$lang['href_edit_topics'] = 					"manage topics";
$lang['href_add_subject_topic'] = 				"add a dicussion under this topic";


// ERR
$lang['err_no_topics'] = 						"Sorry, there are no topics to display.";
$lang['err_no_subjects'] = 						"Sorry, no discussions available.";
$lang['err_no_add_subject'] = 					"sorry, you are not allowed to add a discussion to this topic.";


//icons
$lang['ttl_sticky'] = 							"sticky";
$lang['ttl_locked'] = 							"locked";


//BODY TEXT
$lang['txt_topic'] = 							"topic";
$lang['txt_published_to'] = 					"Published to";
$lang['txt_tag_intro'] = 						"My tags";
$lang['txt_item_tag'] = 						"This discussion is tagged with with";
$lang['txt_forum'] = 							"discussions";//breadcrumb
$lang['txt_total_subjects'] = 					"total subjects";
$lang['txt_search_discussions'] = 				"search for discussions";
$lang['txt_comment_total'] = 					"total comments";
$lang['txt_movement'] = 						"movement";
$lang['txt_lastview'] = 						"last viewed";
$lang['txt_watching'] = 						"marked";
$lang['txt_last_comment'] = 					"last comment";
$lang['txt_topic_role_add'] = 					"The following roles can add subjects to this topic";
$lang['txt_sticky'] = 							"sticky";
$lang['txt_locked'] = 							"locked";
$lang['txt_tag'] = 								"tags";
$lang['txt_options'] = 							"options";
$lang['txt_view'] = 							"view";
$lang['txt_intro_node'] = 						"Listed are the last MAXLISTNUMBER (max) discussions that have been published by a member of this group.";
$lang['txt_intro_network'] = 					"Listed are the last MAXLISTNUMBER (max) discussions that have been published by a person in your network.";
$lang['txt_outro_network'] = 					"The following people in your network have not published a discussion within the last MAXLISTNUMBER.";
$lang['txt_intro_latest'] = 					"These are the latest discussions for the group. If you want to add a discussion click on a topic first.";

?>
